rm(list=ls())

library(tidyverse)
library(curl)
library(forcats)
library(readxl)
library(RcppRoll)
library(cowplot)

#Read in data
temp <- tempfile()
source <- "https://opendata.arcgis.com/datasets/d9be85b30d7748b5b7c09450b8aede63_0.csv?geometry=%7B%22xmin%22%3A-23.251%2C%22ymin%22%3A51.133%2C%22xmax%22%3A6.632%2C%22ymax%22%3A55.71%2C%22type%22%3A%22extent%22%2C%22spatialReference%22%3A%7B%22wkid%22%3A4326%7D%7D"
temp <- curl_download(url=source, destfile=temp, quiet=FALSE, mode="wb")
data <- read_csv(temp)

#Strip out geographical information
data <- data[,c(5,3,4,11,12)]

colnames(data) <- c("TimeStamp", "county", "pop", "cumul_cases", "caseprop")

#Convert timestamp to date
data$date <- as.Date(substr(data$TimeStamp, 1, 10))

#Calculate daily cases
data <- data %>%
  arrange(county, date) %>%
  group_by(county) %>%
  mutate(cases=cumul_cases-lag(cumul_cases,1))

#Add in missing data for 30th June - assume no new cases
temp <- data.frame(date=as.Date("2020-06-30"),
                   county=unique(data$county),
                   cases=0)

data <- bind_rows(data, temp)

#For 3 counties (Leitrim, Limerick and Sligo) the case count goes *down* in early May. Ignore these for now
data$cases <- ifelse(is.na(data$cases), 0, data$cases)
data$cases <- ifelse(data$cases<0, 0, data$cases)
data$cumul_cases <- ifelse(is.na(data$cumul_cases), 0, data$cumul_cases)

heatmap <- data %>%
  group_by(county) %>%
  arrange(date) %>% 
  mutate(casesroll_avg=roll_mean(cases, 7, align="right", fill=0)) %>%
  mutate(maxcaserate=max(casesroll_avg), maxcaseday=date[which(casesroll_avg==maxcaserate)][1],
         totalcases=max(cumul_cases))

heatmap$maxcaseprop <- heatmap$casesroll_avg/heatmap$maxcaserate

#Enter dates to plot from and to
plotfrom <- "2020-03-21"
plotto <- max(heatmap$date)

#Plot case trajectories
casetiles <- ggplot(heatmap, aes(x=date, y=fct_reorder(county, maxcaseday), fill=maxcaseprop))+
  geom_tile(colour="White", show.legend=FALSE)+
  theme_classic()+
  scale_fill_distiller(palette="Spectral")+
  scale_y_discrete(name="", expand=c(0,0))+
  scale_x_date(name="Date", limits=as.Date(c(plotfrom, plotto)), expand=c(0,0))+
  labs(title="Timelines for COVID-19 cases in Irish Counties",
       subtitle=paste0("The heatmap represents the 7-day rolling average of the number of new confirmed cases, normalised to the maximum value within the county.\nCounties are ordered by the date at which they reached their peak number of new cases. Bars on the right represent the absolute number of cases in each county.\nData updated to ", plotto,". Data for most recent days is provisional and may be revised upwards as additional tests are processed."),
       caption="Data from data.gov.ie | Plot by @VictimOfMaths")+
  theme(axis.line.y=element_blank(), plot.subtitle=element_text(size=rel(0.78)), plot.title.position="plot",
        axis.text.y=element_text(colour="Black"))

casebars <- ggplot(subset(heatmap, date==maxcaseday), aes(x=totalcases, y=fct_reorder(county, maxcaseday), fill=totalcases))+
  geom_col(show.legend=FALSE)+
  theme_classic()+
  scale_fill_distiller(palette="Spectral")+
  scale_x_continuous(name="Total confirmed cases", breaks=c(0,5000,10000))+
  theme(axis.title.y=element_blank(), axis.line.y=element_blank(), axis.text.y=element_blank(),
        axis.ticks.y=element_blank(), axis.text.x=element_text(colour="Black"))

tiff("Outputs/COVIDIrishLACasesHeatmap.tiff", units="in", width=11, height=6, res=500)
plot_grid(casetiles, casebars, align="h", rel_widths=c(1,0.2))
dev.off()

library(ggridges)

tiff("Outputs/COVIDIrishCountyCaseRidges.tiff", units="in", width=11, height=6, res=500)
ggplot(heatmap, aes(x=date, y=fct_reorder(county, totalcases), height=casesroll_avg, fill=casesroll_avg))+
  geom_density_ridges_gradient(stat="identity", rel_min_height=0.007)+
  theme_classic()+
  scale_fill_distiller(palette="Spectral", name="Cases per day\n7-day rolling avg.")+
  scale_x_date(name="Date", limits=as.Date(c(plotfrom, plotto)), expand=c(0,0))+
  scale_y_discrete(name="")+
  labs(title="Timelines of confirmed COVID-19 cases in Irish counties",
       caption="Data from data.gov.ie | Plot by @VictimOfMaths")
dev.off()
